@@ -31,20 +31,20 @@ class BackupTests(unittest.TestCase):
     def setUp(self, m):
         self.b = b.Backup(v.auth_url, v.username, v.password)
 
-    @patch('swiftsc.client.is_container', return_value=201)
+    @patch('swiftsc.client.is_container', return_value=True)
     @patch('swiftsc.client.list_objects', return_value=v.objects)
     @patch('swiftsc.client.create_object', return_value=201)
     def test_backup(self, m1, m2, m3):
         self.assertEqual(self.b.backup("."), True)
 
-    @patch('swiftsc.client.is_container', return_value=204)
+    @patch('swiftsc.client.is_container', return_value=True)
     @patch('swiftsc.client.create_container', return_value=201)
     @patch('swiftsc.client.list_objects', return_value=v.objects)
     @patch('swiftsc.client.create_object', return_value=201)
     def test_backup_file_with_create_cont(self, m1, m2, m3, m4):
         self.assertEqual(self.b.backup_file("examples/bu2sw.conf"), True)
 
-    @patch('swiftsc.client.is_container', return_value=204)
+    @patch('swiftsc.client.is_container', return_value=True)
     @patch('swiftsc.client.create_container', return_value=202)
     @patch('swiftsc.client.list_objects', return_value=v.objects)
     @patch('swiftsc.client.create_object', return_value=201)
@@ -52,19 +52,19 @@ class BackupTests(unittest.TestCase):
         self.assertEqual(self.b.backup_file("examples/bu2sw.conf"), True)
 
     @unittest.expectedFailure
-    @patch('swiftsc.client.is_container', return_value=204)
+    @patch('swiftsc.client.is_container', return_value=True)
     @patch('swiftsc.client.create_container', return_value=400)
     def test_backup_faile_fail_create_cont(self, m1, m2):
         self.assertEqual(self.b.backup_file("examples/bu2sw.conf"), True)
 
-    @patch('swiftsc.client.is_container', return_value=204)
+    @patch('swiftsc.client.is_container', return_value=True)
     @patch('swiftsc.client.create_container', return_value=202)
     @patch('swiftsc.client.list_objects', return_value=v.objects)
     @patch('swiftsc.client.create_object', return_value=201)
     def test_backup_file_create_object(self, m1, m2, m3, m4):
         self.assertEqual(self.b.backup_file("examples/bu2sw.conf"), True)
 
-    @patch('swiftsc.client.is_container', return_value=201)
+    @patch('swiftsc.client.is_container', return_value=True)
     @patch('swiftsc.client.create_container', return_value=201)
     @patch('swiftsc.client.list_objects', return_value=v.objects)
     @patch('swiftsc.client.create_object', return_value=202)
@@ -72,7 +72,7 @@ class BackupTests(unittest.TestCase):
         self.assertEqual(self.b.backup_file("examples/bu2sw.conf"), True)
 
     @unittest.expectedFailure
-    @patch('swiftsc.client.is_container', return_value=201)
+    @patch('swiftsc.client.is_container', return_value=True)
     @patch('swiftsc.client.create_container', return_value=201)
     @patch('swiftsc.client.list_objects', return_value=v.objects)
     @patch('swiftsc.client.create_object', return_value=400)
@@ -107,7 +107,7 @@ class BackupTests(unittest.TestCase):
         self.assertEqual(self.b.rotate(v.test_file, v.object_name,
                                        v.objects_name_l), True)
 
-    @patch('swiftsc.client.is_container', return_value=201)
+    @patch('swiftsc.client.is_container', return_value=True)
     @patch('swiftsc.client.list_objects', return_value=v.objects)
     def test_retrieve_backup_data_list(self, m1, m2):
         self.assertEqual(self.b.retrieve_backup_data_list(),
@@ -115,7 +115,31 @@ class BackupTests(unittest.TestCase):
         self.assertEqual(self.b.retrieve_backup_data_list(True),
                          v.objects)
 
-    @patch('swiftsc.client.is_container', return_value=404)
+    @patch('swiftsc.client.is_container', return_value=False)
     def test_retrieve_backup_data_list(self, m):
         self.assertEqual(self.b.retrieve_backup_data_list(),
                          [])
+
+    @patch('swiftsc.client.is_container', return_value=True)
+    @patch('swiftsc.client.is_object', return_value=True)
+    @patch('swiftsc.client.delete_object', return_value=204)
+    def test_delete_backup_data(self, m1, m2, m3):
+        self.assertEqual(self.b.delete_backup_data("dummy"), True)
+
+    @unittest.expectedFailure
+    @patch('swiftsc.client.is_container', return_value=False)
+    def test_delete_backup_data_without_container(self, m):
+        self.assertEqual(self.b.delete_backup_data("dummy"), True)
+
+    @unittest.expectedFailure
+    @patch('swiftsc.client.is_container', return_value=True)
+    @patch('swiftsc.client.is_object', return_value=False)
+    def test_delete_backup_data_without_object(self, m1, m2):
+        self.assertEqual(self.b.delete_backup_data("dummy"), True)
+
+    @unittest.expectedFailure
+    @patch('swiftsc.client.is_container', return_value=True)
+    @patch('swiftsc.client.is_object', return_value=True)
+    @patch('swiftsc.client.delete_object', return_value=False)
+    def test_delete_backup_data_runtime_error(self, m1, m2, m3):
+        self.assertEqual(self.b.delete_backup_data("dummy"), True)
